@@ -27,8 +27,10 @@
 #include "gedit-commands-private.h"
 #include "gedit-multi-notebook.h"
 
-struct _GeditNotebookPopupMenuPrivate
+struct _GeditNotebookPopupMenu
 {
+	GtkMenu parent_instance;
+
 	GeditWindow *window;
 	GeditTab *tab;
 
@@ -39,10 +41,13 @@ enum
 {
 	PROP_0,
 	PROP_WINDOW,
-	PROP_TAB
+	PROP_TAB,
+	LAST_PROP
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GeditNotebookPopupMenu, gedit_notebook_popup_menu, GTK_TYPE_MENU)
+static GParamSpec *properties[LAST_PROP];
+
+G_DEFINE_TYPE (GeditNotebookPopupMenu, gedit_notebook_popup_menu, GTK_TYPE_MENU)
 
 static void
 gedit_notebook_popup_menu_set_property (GObject      *object,
@@ -55,11 +60,11 @@ gedit_notebook_popup_menu_set_property (GObject      *object,
 	switch (prop_id)
 	{
 		case PROP_WINDOW:
-			menu->priv->window = GEDIT_WINDOW (g_value_get_object (value));
+			menu->window = GEDIT_WINDOW (g_value_get_object (value));
 			break;
 
 		case PROP_TAB:
-			menu->priv->tab = GEDIT_TAB (g_value_get_object (value));
+			menu->tab = GEDIT_TAB (g_value_get_object (value));
 			break;
 
 		default:
@@ -79,11 +84,11 @@ gedit_notebook_popup_menu_get_property (GObject    *object,
 	switch (prop_id)
 	{
 		case PROP_WINDOW:
-			g_value_set_object (value, menu->priv->window);
+			g_value_set_object (value, menu->window);
 			break;
 
 		case PROP_TAB:
-			g_value_set_object (value, menu->priv->tab);
+			g_value_set_object (value, menu->tab);
 			break;
 
 		default:
@@ -92,12 +97,6 @@ gedit_notebook_popup_menu_get_property (GObject    *object,
 	}
 }
 
-static void
-gedit_notebook_popup_menu_finalize (GObject *object)
-{
-	G_OBJECT_CLASS (gedit_notebook_popup_menu_parent_class)->finalize (object);
-}
-
 static void
 update_sensitivity (GeditNotebookPopupMenu *menu)
 {
@@ -109,16 +108,16 @@ update_sensitivity (GeditNotebookPopupMenu *menu)
 	guint n_tabs;
 	GAction *action;
 
-	state = gedit_tab_get_state (menu->priv->tab);
+	state = gedit_tab_get_state (menu->tab);
 
-	mnb = GEDIT_MULTI_NOTEBOOK (_gedit_window_get_multi_notebook (menu->priv->window));
+	mnb = GEDIT_MULTI_NOTEBOOK (_gedit_window_get_multi_notebook (menu->window));
 
-	notebook = GTK_NOTEBOOK (gedit_multi_notebook_get_notebook_for_tab (mnb, menu->priv->tab));
+	notebook = GTK_NOTEBOOK (gedit_multi_notebook_get_notebook_for_tab (mnb, menu->tab));
 	n_pages = gtk_notebook_get_n_pages (notebook);
 	n_tabs = gedit_multi_notebook_get_n_tabs(mnb);
-	page_num = gtk_notebook_page_num (notebook, GTK_WIDGET (menu->priv->tab));
+	page_num = gtk_notebook_page_num (notebook, GTK_WIDGET (menu->tab));
 
-	action = g_action_map_lookup_action (G_ACTION_MAP (menu->priv->action_group),
+	action = g_action_map_lookup_action (G_ACTION_MAP (menu->action_group),
 	                                     "close");
 	g_simple_action_set_enabled (G_SIMPLE_ACTION (action),
 				     (state != GEDIT_TAB_STATE_CLOSING) &&
@@ -127,19 +126,19 @@ update_sensitivity (GeditNotebookPopupMenu *menu)
 				     (state != GEDIT_TAB_STATE_PRINTING) &&
 				     (state != GEDIT_TAB_STATE_SAVING_ERROR));
 
-	action = g_action_map_lookup_action (G_ACTION_MAP (menu->priv->action_group),
+	action = g_action_map_lookup_action (G_ACTION_MAP (menu->action_group),
 	                                     "move-to-new-window");
 	g_simple_action_set_enabled (G_SIMPLE_ACTION (action), n_tabs > 1);
 
-	action = g_action_map_lookup_action (G_ACTION_MAP (menu->priv->action_group),
+	action = g_action_map_lookup_action (G_ACTION_MAP (menu->action_group),
 	                                     "move-to-new-tab-group");
 	g_simple_action_set_enabled (G_SIMPLE_ACTION (action), n_pages > 1);
 
-	action = g_action_map_lookup_action (G_ACTION_MAP (menu->priv->action_group),
+	action = g_action_map_lookup_action (G_ACTION_MAP (menu->action_group),
 	                                     "move-left");
 	g_simple_action_set_enabled (G_SIMPLE_ACTION (action), page_num > 0);
 
-	action = g_action_map_lookup_action (G_ACTION_MAP (menu->priv->action_group),
+	action = g_action_map_lookup_action (G_ACTION_MAP (menu->action_group),
 	                                     "move-right");
 	g_simple_action_set_enabled (G_SIMPLE_ACTION (action), page_num < n_pages - 1);
 }
@@ -162,25 +161,22 @@ gedit_notebook_popup_menu_class_init (GeditNotebookPopupMenuClass *klass)
 	object_class->get_property = gedit_notebook_popup_menu_get_property;
 	object_class->set_property = gedit_notebook_popup_menu_set_property;
 	object_class->constructed = gedit_notebook_popup_menu_constructed;
-	object_class->finalize = gedit_notebook_popup_menu_finalize;
 
-	g_object_class_install_property (object_class,
-	                                 PROP_WINDOW,
-	                                 g_param_spec_object ("window",
-	                                                      "Window",
-	                                                      "The GeditWindow",
-	                                                      GEDIT_TYPE_WINDOW,
-	                                                      G_PARAM_READWRITE |
-	                                                      G_PARAM_CONSTRUCT_ONLY));
+	properties[PROP_WINDOW] =
+		g_param_spec_object ("window",
+		                     "Window",
+		                     "The GeditWindow",
+		                     GEDIT_TYPE_WINDOW,
+		                     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_property (object_class,
-	                                 PROP_TAB,
-	                                 g_param_spec_object ("tab",
-	                                                      "Tab",
-	                                                      "The GeditTab",
-	                                                      GEDIT_TYPE_TAB,
-	                                                      G_PARAM_READWRITE |
-	                                                      G_PARAM_CONSTRUCT_ONLY));
+	properties[PROP_TAB] =
+		g_param_spec_object ("tab",
+		                     "Tab",
+		                     "The GeditTab",
+		                     GEDIT_TYPE_TAB,
+		                     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+
+	g_object_class_install_properties (object_class, LAST_PROP, properties);
 }
 
 static void
@@ -193,14 +189,15 @@ on_move_left_activate (GSimpleAction *action,
 	GtkNotebook *notebook;
 	gint page_num;
 
-	mnb = GEDIT_MULTI_NOTEBOOK (_gedit_window_get_multi_notebook (menu->priv->window));
+	mnb = GEDIT_MULTI_NOTEBOOK (_gedit_window_get_multi_notebook (menu->window));
 
-	notebook = GTK_NOTEBOOK (gedit_multi_notebook_get_notebook_for_tab (mnb, menu->priv->tab));
-	page_num = gtk_notebook_page_num (notebook, GTK_WIDGET (menu->priv->tab));
+	notebook = GTK_NOTEBOOK (gedit_multi_notebook_get_notebook_for_tab (mnb, menu->tab));
+	page_num = gtk_notebook_page_num (notebook, GTK_WIDGET (menu->tab));
 
 	if (page_num > 0)
 	{
-		gtk_notebook_reorder_child (notebook, GTK_WIDGET (menu->priv->tab),
+		gtk_notebook_reorder_child (notebook,
+		                            GTK_WIDGET (menu->tab),
 		                            page_num - 1);
 	}
 }
@@ -216,15 +213,16 @@ on_move_right_activate (GSimpleAction *action,
 	gint page_num;
 	gint n_pages;
 
-	mnb = GEDIT_MULTI_NOTEBOOK (_gedit_window_get_multi_notebook (menu->priv->window));
+	mnb = GEDIT_MULTI_NOTEBOOK (_gedit_window_get_multi_notebook (menu->window));
 
-	notebook = GTK_NOTEBOOK (gedit_multi_notebook_get_notebook_for_tab (mnb, menu->priv->tab));
+	notebook = GTK_NOTEBOOK (gedit_multi_notebook_get_notebook_for_tab (mnb, menu->tab));
 	n_pages = gtk_notebook_get_n_pages (notebook);
-	page_num = gtk_notebook_page_num (notebook, GTK_WIDGET (menu->priv->tab));
+	page_num = gtk_notebook_page_num (notebook, GTK_WIDGET (menu->tab));
 
 	if (page_num <  (n_pages - 1))
 	{
-		gtk_notebook_reorder_child (notebook, GTK_WIDGET (menu->priv->tab),
+		gtk_notebook_reorder_child (notebook,
+		                            GTK_WIDGET (menu->tab),
 		                            page_num + 1);
 	}
 }
@@ -236,8 +234,7 @@ on_move_to_new_window_activate (GSimpleAction *action,
 {
 	GeditNotebookPopupMenu *menu = GEDIT_NOTEBOOK_POPUP_MENU (user_data);
 
-	_gedit_window_move_tab_to_new_window (menu->priv->window,
-	                                      menu->priv->tab);
+	_gedit_window_move_tab_to_new_window (menu->window, menu->tab);
 }
 
 static void
@@ -247,8 +244,7 @@ on_move_to_new_tab_group_activate (GSimpleAction *action,
 {
 	GeditNotebookPopupMenu *menu = GEDIT_NOTEBOOK_POPUP_MENU (user_data);
 
-	_gedit_window_move_tab_to_new_tab_group (menu->priv->window,
-	                                         menu->priv->tab);
+	_gedit_window_move_tab_to_new_tab_group (menu->window, menu->tab);
 }
 
 static void
@@ -258,7 +254,7 @@ on_close_activate (GSimpleAction *action,
 {
 	GeditNotebookPopupMenu *menu = GEDIT_NOTEBOOK_POPUP_MENU (user_data);
 
-	_gedit_cmd_file_close_tab (menu->priv->tab, menu->priv->window);
+	_gedit_cmd_file_close_tab (menu->tab, menu->window);
 }
 
 static GActionEntry action_entries[] = {
@@ -272,22 +268,20 @@ static GActionEntry action_entries[] = {
 static void
 gedit_notebook_popup_menu_init (GeditNotebookPopupMenu *menu)
 {
-	menu->priv = gedit_notebook_popup_menu_get_instance_private (menu);
-
 	gtk_menu_shell_bind_model (GTK_MENU_SHELL (menu),
 	                           _gedit_app_get_notebook_menu (GEDIT_APP (g_application_get_default ())),
 	                           "popup",
 	                           TRUE);
 
-	menu->priv->action_group = g_simple_action_group_new ();
-	g_action_map_add_action_entries (G_ACTION_MAP (menu->priv->action_group),
+	menu->action_group = g_simple_action_group_new ();
+	g_action_map_add_action_entries (G_ACTION_MAP (menu->action_group),
 	                                 action_entries,
 	                                 G_N_ELEMENTS (action_entries),
 	                                 menu);
 
 	gtk_widget_insert_action_group (GTK_WIDGET (menu),
 	                                "popup",
-	                                G_ACTION_GROUP (menu->priv->action_group));
+	                                G_ACTION_GROUP (menu->action_group));
 }
 
 GtkWidget *
@@ -299,3 +293,5 @@ gedit_notebook_popup_menu_new (GeditWindow *window,
 	                     "tab", tab,
 	                     NULL);
 }
+
+/* ex:set ts=8 noet: */
