@@ -34,9 +34,7 @@ typedef enum
 	GEDIT_TAB_STATE_REVERTING,
 	GEDIT_TAB_STATE_SAVING,
 	GEDIT_TAB_STATE_PRINTING,
-	GEDIT_TAB_STATE_PRINT_PREVIEWING, /* unused, deprecated */
 	GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW,
-	GEDIT_TAB_STATE_GENERIC_NOT_EDITABLE, /* unused, deprecated */
 	GEDIT_TAB_STATE_LOADING_ERROR,
 	GEDIT_TAB_STATE_REVERTING_ERROR,
 	GEDIT_TAB_STATE_SAVING_ERROR,
