@@ -3,7 +3,7 @@
  * This file is part of gedit
  *
  * Copyright (C) 2010 - Ignacio Casal Quinteiro
- * Copyright (C) 2013 - Sébastien Wilmet
+ * Copyright (C) 2013, 2019 - Sébastien Wilmet
  *
  * gedit is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 #include <glib/gi18n.h>
 #include <stdlib.h>
 
-#include "gedit-view-centering.h"
 #include "gedit-debug.h"
 #include "gedit-utils.h"
 #include "gedit-settings.h"
@@ -54,11 +53,7 @@ struct _GeditViewFrame
 {
 	GtkOverlay parent_instance;
 
-	GSettings *editor_settings;
-
 	GeditView *view;
-	GeditViewCentering *view_centering;
-	GtkFrame *map_frame;
 
 	SearchMode search_mode;
 
@@ -164,7 +159,6 @@ gedit_view_frame_dispose (GObject *object)
 		gtk_source_file_set_mount_operation_factory (file, NULL, NULL, NULL);
 	}
 
-	g_clear_object (&frame->editor_settings);
 	g_clear_object (&frame->entry_tag);
 	g_clear_object (&frame->search_settings);
 	g_clear_object (&frame->old_search_settings);
@@ -938,10 +932,7 @@ search_entry_icon_release (GtkEntry             *entry,
 			  G_CALLBACK (gtk_widget_destroy),
 			  NULL);
 
-	gtk_menu_popup (GTK_MENU (menu),
-	                NULL, NULL,
-	                gedit_utils_menu_position_under_widget, entry,
-	                event->button, event->time);
+	gtk_menu_popup_at_widget (GTK_MENU (menu), GTK_WIDGET (entry), GDK_GRAVITY_SOUTH_WEST, GDK_GRAVITY_NORTH_WEST, NULL);
 }
 
 static void
@@ -1441,8 +1432,6 @@ gedit_view_frame_class_init (GeditViewFrameClass *klass)
 	gtk_widget_class_set_template_from_resource (widget_class,
 	                                             "/org/gnome/gedit/ui/gedit-view-frame.ui");
 	gtk_widget_class_bind_template_child (widget_class, GeditViewFrame, view);
-	gtk_widget_class_bind_template_child (widget_class, GeditViewFrame, view_centering);
-	gtk_widget_class_bind_template_child (widget_class, GeditViewFrame, map_frame);
 	gtk_widget_class_bind_template_child (widget_class, GeditViewFrame, revealer);
 	gtk_widget_class_bind_template_child (widget_class, GeditViewFrame, search_entry);
 	gtk_widget_class_bind_template_child (widget_class, GeditViewFrame, go_up_button);
@@ -1464,21 +1453,11 @@ gedit_view_frame_init (GeditViewFrame *frame)
 {
 	GeditDocument *doc;
 	GtkSourceFile *file;
-	GdkRGBA transparent = {0, 0, 0, 0};
 
 	gedit_debug (DEBUG_WINDOW);
 
 	gtk_widget_init_template (GTK_WIDGET (frame));
 
-	frame->editor_settings = g_settings_new ("org.gnome.gedit.preferences.editor");
-	g_settings_bind (frame->editor_settings,
-	                 GEDIT_SETTINGS_DISPLAY_OVERVIEW_MAP,
-	                 frame->map_frame,
-	                 "visible",
-	                 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_NO_SENSITIVITY);
-
-	gtk_widget_override_background_color (GTK_WIDGET (frame), 0, &transparent);
-
 	doc = get_document (frame);
 	file = gedit_document_get_file (doc);
 
@@ -1576,14 +1555,6 @@ gedit_view_frame_new (void)
 	return g_object_new (GEDIT_TYPE_VIEW_FRAME, NULL);
 }
 
-GeditViewCentering *
-gedit_view_frame_get_view_centering (GeditViewFrame *frame)
-{
-	g_return_val_if_fail (GEDIT_IS_VIEW_FRAME (frame), NULL);
-
-	return frame->view_centering;
-}
-
 GeditView *
 gedit_view_frame_get_view (GeditViewFrame *frame)
 {
